@@ -10,6 +10,7 @@ except ImportError:
 
 
 PROGRAMNAME = 'pter'
+QTPROGRAMNAME = 'qpter'
 HERE = pathlib.Path(os.path.abspath(__file__)).parent
 HOME = pathlib.Path.home()
 CONFIGDIR = HOME / ".config" / PROGRAMNAME
@@ -20,7 +21,7 @@ CACHEFILE = CACHEDIR / (PROGRAMNAME + ".settings")
 if BaseDirectory is not None:
     CONFIGDIR = pathlib.Path(BaseDirectory.save_config_path(PROGRAMNAME) or CONFIGDIR)
     CONFIGFILE = CONFIGDIR / (PROGRAMNAME + ".conf")
-    CACHEDIR = pathlib.Path(BaseDirectory.save_config_path(PROGRAMNAME) or CACHEDIR)
+    CACHEDIR = pathlib.Path(BaseDirectory.save_cache_path(PROGRAMNAME) or CACHEDIR)
     CACHEFILE = CACHEDIR / (PROGRAMNAME + ".settings")
 
 SEARCHES_FILE = CONFIGDIR / "searches.txt"
@@ -32,6 +33,7 @@ ATTR_TRACKING = 'tracking'
 ATTR_T = 't'
 ATTR_DUE = 'due'
 ATTR_PRI = 'pri'
+ATTR_ID = 'id'
 
 DELEGATE_ACTION_NONE = 'none'
 DELEGATE_ACTION_MAIL = 'mail-to'
@@ -46,6 +48,7 @@ SETTING_GROUP_EDITORKEYS = 'Editor:Keys'
 SETTING_GROUP_GUICOLORS = 'GUI:Colors'
 SETTING_GROUP_GUIHIGHLIGHT = 'GUI:Highlight'
 SETTING_GROUP_GUIKEYS = 'GUI:Keys'
+SETTING_GROUP_GUI = 'GUI'
 SETTING_HUMAN_DATES = 'human-friendly-dates'
 SETTING_PROTOCOLS = 'protocols'
 SETTING_DELEG_MARKER = 'delegation-marker'
@@ -60,6 +63,13 @@ SETTING_SHOW_NUMBERS = 'show-numbers'
 SETTING_USE_COLORS = 'use-colors'
 SETTING_TASK_FORMAT = 'task-format'
 SETTING_CLEAR_CONTEXT = 'clear-context'
+SETTING_FONT = 'font'
+SETTING_FONTSIZE = 'font-size'
+SETTING_SINGLE_INSTANCE = 'single-instance'
+SETTING_CREATE_FROM_SEARCH = 'create-from-search'
+SETTING_AUTO_ID = 'auto-id'
+SETTING_HIDE_SEQUENTIAL = 'hide-sequential'
+SETTING_CLICKABLE = 'clickable'
 SETTING_ICON_SELECTION = 'selection'
 SETTING_ICON_NOT_DONE = 'not-done'
 SETTING_ICON_DONE = 'done'
@@ -84,8 +94,11 @@ SETTING_COL_OVERDUE = 'overdue'
 SETTING_COL_DUE_TODAY = 'due-today'
 SETTING_COL_DUE_TOMORROW = 'due-tomorrow'
 SETTING_COL_TRACKING = 'tracking'
+SETTING_COL_URL = 'url'
 SETTING_GK_QUIT = 'quit'
 SETTING_GK_NEW = 'new'
+SETTING_GK_NEW_REF = 'new-related'
+SETTING_GK_NEW_AFTER = 'new-subsequent'
 SETTING_GK_EDIT = 'edit'
 SETTING_GK_OPEN_FILE = 'open-file'
 SETTING_GK_TOGGLE_DONE = 'toggle-done'
